@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -277,17 +249,17 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
      * @return The client
      */
     private SproxydClient initClient(String filestoreID, String prefix) throws OXException {
-        return new SproxydClient(services, initSproxydConfig(filestoreID), prefix, filestoreID);
+        return new SproxydClient(services, getEndpointPoolFor(filestoreID), prefix, filestoreID);
     }
 
     /**
-     * Gets the HTTP client and endpoint pool for a configured denoted sproxyd filestore.
+     * Gets the end-point pool for specified Sproxyd filestore.
      *
-     * @param filestoreID The filestore ID
-     * @return The endpoint pool
-     * @throws OXException If endpoint pool cannot be initialized
+     * @param filestoreID The filestore identifier
+     * @return The end-point pool
+     * @throws OXException If end-point pool cannot be initialized
      */
-    private EndpointPool initSproxydConfig(String filestoreID) throws OXException {
+    private EndpointPool getEndpointPoolFor(String filestoreID) throws OXException {
         EndpointPool endpointPool = endpointPoolCache.getIfPresent(filestoreID);
         if (endpointPool == null) {
             try {
@@ -297,20 +269,20 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
                 if (cause instanceof OXException) {
                     throw (OXException) cause;
                 }
-                throw OXException.general("Failed initializing S3 client.", cause);
+                throw OXException.general("Failed initializing Sproxyd end-point pool.", cause);
             }
         }
         return endpointPool;
     }
 
     /**
-     * Initializes a new HTTP client and endpoint pool for a configured sproxyd filestore.
+     * Initializes a end-point pool for specified Sproxyd filestore.
      *
-     * @param filestoreID The filestore ID
-     * @return The new endpoint pool
-     * @throws OXException If endpoint pool cannot be initialized
+     * @param filestoreID The filestore identifier
+     * @return The new end-point pool
+     * @throws OXException If end-point pool cannot be initialized
      */
-    EndpointPool doInitSproxydConfig(String filestoreID) throws OXException {
+    EndpointPool initEndpointPoolFor(String filestoreID) throws OXException {
         ConfigurationService configService = services.getService(ConfigurationService.class);
         PropertyNameBuilder nameBuilder = new PropertyNameBuilder("com.openexchange.filestore.sproxyd.");
         // End-point configuration
@@ -391,7 +363,7 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
 
         @Override
         public EndpointPool call() throws Exception {
-            return factory.doInitSproxydConfig(filestoreID);
+            return factory.initEndpointPoolFor(filestoreID);
         }
     }
 
