@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -53,9 +25,12 @@ import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.util.ArrayList;
 import java.util.Collections;
-import java.util.LinkedList;
+import java.util.LinkedHashSet;
 import java.util.List;
+import java.util.Optional;
+import java.util.Set;
 import java.util.UUID;
 import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
@@ -123,18 +98,18 @@ public class RdbChunkStorage implements ChunkStorage {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
-            stmt = con.prepareStatement("SELECT DISTINCT document_id FROM scality_filestore WHERE cid=? AND user=?");
+            stmt = con.prepareStatement("SELECT document_id FROM scality_filestore WHERE cid=? AND user=?");
             stmt.setInt(1, contextId);
             stmt.setInt(2, userId);
             rs = stmt.executeQuery();
             if (!rs.next()) {
                 return Collections.emptyList();
             }
-            List<UUID> documentIds = new LinkedList<UUID>();
+            Set<UUID> documentIds = new LinkedHashSet<>();
             do {
                 documentIds.add(UUIDs.toUUID(rs.getBytes(1)));
             } while (rs.next());
-            return documentIds;
+            return new ArrayList<>(documentIds);
         } catch (SQLException e) {
             throw SproxydExceptionCode.SQL_ERROR.create(e, e.getMessage());
         } finally {
@@ -146,23 +121,27 @@ public class RdbChunkStorage implements ChunkStorage {
     public List<Chunk> getChunks(UUID documentId) throws OXException {
         Connection con = databaseAccess.acquireReadOnly();
         try {
-            return getChunks(documentId, userId, contextId, true, con);
+            Optional<List<Chunk>> optionalChunks = getChunks(documentId, userId, contextId, con);
+            if (optionalChunks.isPresent()) {
+                return optionalChunks.get();
+            }
+            throw SproxydExceptionCode.NO_SUCH_DOCUMENT.create(UUIDs.getUnformattedString(documentId));
         } finally {
             databaseAccess.releaseReadOnly(con);
         }
     }
 
     @Override
-    public List<Chunk> optChunks(UUID documentId) throws OXException {
+    public Optional<List<Chunk>> optChunks(UUID documentId) throws OXException {
         Connection con = databaseAccess.acquireReadOnly();
         try {
-            return getChunks(documentId, userId, contextId, false, con);
+            return getChunks(documentId, userId, contextId, con);
         } finally {
             databaseAccess.releaseReadOnly(con);
         }
     }
 
-    private static List<Chunk> getChunks(UUID documentId, int userId, int contextId, boolean errorOnAbsence, Connection con) throws OXException {
+    private static Optional<List<Chunk>> getChunks(UUID documentId, int userId, int contextId, Connection con) throws OXException {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -172,18 +151,15 @@ public class RdbChunkStorage implements ChunkStorage {
             stmt.setBytes(3, UUIDs.toByteArray(documentId));
             rs = stmt.executeQuery();
             if (!rs.next()) {
-                if (errorOnAbsence) {
-                    throw SproxydExceptionCode.NO_SUCH_DOCUMENT.create(UUIDs.getUnformattedString(documentId));
-                }
-                return Collections.emptyList();
+                return Optional.empty();
             }
 
-            List<Chunk> chunks = new LinkedList<Chunk>();
+            List<Chunk> chunks = new ArrayList<Chunk>();
             do {
                 chunks.add(new Chunk(documentId, UUIDs.toUUID(rs.getBytes(1)), rs.getLong(2), rs.getLong(3)));
             } while (rs.next());
             Collections.sort(chunks);
-            return chunks;
+            return Optional.of(chunks);
         } catch (SQLException e) {
             throw SproxydExceptionCode.SQL_ERROR.create(e, e.getMessage());
         } finally {
@@ -254,10 +230,10 @@ public class RdbChunkStorage implements ChunkStorage {
     }
 
     @Override
-    public Chunk getLastChunk(UUID documentId) throws OXException {
+    public Optional<Chunk> getLastChunk(UUID documentId) throws OXException {
         Connection con = databaseAccess.acquireReadOnly();
         try {
-            return getLastChunk(documentId, userId, contextId, con);
+            return Optional.ofNullable(getLastChunk(documentId, userId, contextId, con));
         } finally {
             databaseAccess.releaseReadOnly(con);
         }
