@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -52,6 +24,7 @@ package com.openexchange.filestore.sproxyd.impl;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Collection;
+import java.util.Optional;
 import java.util.UUID;
 import java.util.concurrent.Callable;
 import java.util.concurrent.TimeUnit;
@@ -67,6 +40,8 @@ import com.openexchange.filestore.FileStorageCodes;
 import com.openexchange.filestore.sproxyd.SproxydExceptionCode;
 import com.openexchange.java.util.UUIDs;
 import com.openexchange.rest.client.httpclient.HttpClientService;
+import com.openexchange.rest.client.httpclient.HttpClients;
+import com.openexchange.rest.client.httpclient.HttpClients.HttpResponseStream;
 import com.openexchange.server.ServiceLookup;
 import net.jodah.failsafe.Failsafe;
 import net.jodah.failsafe.FailsafeException;
@@ -177,22 +152,42 @@ public class SproxydClient {
      * @throws OXException If stored object's input stream cannot be returned
      */
     public InputStream get(UUID id, long rangeStart, long rangeEnd) throws OXException {
-        Callable<InputStream> getDataCallable = new Callable<InputStream>() {
+        HttpResponseStream responseStream = nonResumingGet(id, rangeStart, rangeEnd);
+        if (0 >= rangeStart && 0 >= rangeEnd) {
+            // No range
+            return new ResumableInputStream(responseStream, id, this);
+        }
+        return new RangeAcceptingResumableInputStream(responseStream, new long[] { rangeStart, rangeEnd }, id, this);
+    }
+
+    /**
+     * Gets the input stream of a stored object.
+     *
+     * @param id The identifier of the object
+     * @param rangeStart The (inclusive) start of the requested byte range, or a value equal or smaller <code>0</code> if not used
+     * @param rangeEnd The (inclusive) end of the requested byte range, or a value equal or smaller <code>0</code> if not used
+     * @return The object's input stream
+     * @throws OXException If stored object's input stream cannot be returned
+     */
+    HttpResponseStream nonResumingGet(UUID id, long rangeStart, long rangeEnd) throws OXException {
+        Callable<HttpResponseStream> getDataCallable = new Callable<HttpResponseStream>() {
 
             @Override
-            public InputStream call() throws Exception {
+            public HttpResponseStream call() throws Exception {
                 HttpGet get = null;
                 HttpResponse response = null;
                 Endpoint endpoint = getEndpoint();
                 try {
-                    get = new HttpGet(endpoint.getObjectUrl(id));
+                    String url = endpoint.getObjectUrl(id);
+                    get = new HttpGet(url);
                     if (0 < rangeStart || 0 < rangeEnd) {
                         get.addHeader("Range", "bytes=" + rangeStart + "-" + rangeEnd);
                     }
-                    response = getHttpClient().execute(get);
+                    HttpClient httpClient = getHttpClient();
+                    response = httpClient.execute(get);
                     int status = response.getStatusLine().getStatusCode();
                     if (HttpServletResponse.SC_OK == status || HttpServletResponse.SC_PARTIAL_CONTENT == status) {
-                        InputStream content = response.getEntity().getContent();
+                        HttpResponseStream content = HttpClients.createContentLengthIgnoringHttpResponseStreamFor(response, Optional.of(get));
                         response = null;
                         get = null;
                         return content;
